Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1114)

Unified Diff: remoting/protocol/input_event_tracker.h

Issue 799233004: Add touch events to the protocol, the stub layer, and to the client plugin. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebased Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/client_event_dispatcher.cc ('k') | remoting/protocol/input_event_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/input_event_tracker.h
diff --git a/remoting/protocol/input_event_tracker.h b/remoting/protocol/input_event_tracker.h
index e167cd2bb16688b073b8c23918dc660c35b07633..e83b269f8d5cd93ba6f15ccf6ecfeacdabd01ce7 100644
--- a/remoting/protocol/input_event_tracker.h
+++ b/remoting/protocol/input_event_tracker.h
@@ -29,14 +29,15 @@ class InputEventTracker : public InputStub {
// Returns the count of keys currently pressed.
int PressedKeyCount() const;
// Dispatch release events for all currently-pressed keys and mouse buttons
// to the InputStub.
void ReleaseAll();
// InputStub interface.
void InjectKeyEvent(const KeyEvent& event) override;
void InjectTextEvent(const TextEvent& event) override;
void InjectMouseEvent(const MouseEvent& event) override;
+ void InjectTouchEvent(const TouchEvent& event) override;
private:
protocol::InputStub* input_stub_;
@@ -46,6 +47,8 @@ class InputEventTracker : public InputStub {
webrtc::DesktopVector mouse_pos_;
uint32 mouse_button_state_;
+ std::set<uint32> touch_point_ids_;
+
DISALLOW_COPY_AND_ASSIGN(InputEventTracker);
};
« no previous file with comments | « remoting/protocol/client_event_dispatcher.cc ('k') | remoting/protocol/input_event_tracker.cc » ('j') | no next file with comments »
@@ -29,14 +29,15 @@ class InputEventTracker : public InputStub {
// Returns the count of keys currently pressed.
int PressedKeyCount() const;
- // Dispatch release events for all currently-pressed keys and mouse buttons
- // to the InputStub.
+ // Dispatch release events for all currently-pressed keys, mouse buttons, and
+ // touch points to the InputStub.
void ReleaseAll();
// InputStub interface.

Powered by Google App Engine
This is Rietveld 408576698